#[repr(u32)]pub enum CpuPowerElement {
Cpu = 1,
}Expand description
Represents the power elements related to controlling the CPU. This is an enum with a single variant to add flexibility for future addition of more elements related to CPU power state.
Variants
Cpu = 1