pub struct ComponentPowerConfiguration {
pub power_elements: Vec<PowerElementConfiguration>,
}Expand description
The configuration for a component’s power elements.
Fields
power_elements: Vec<PowerElementConfiguration>Trait Implementations
Sourceimpl Clone for ComponentPowerConfiguration
impl Clone for ComponentPowerConfiguration
Sourcefn clone(&self) -> ComponentPowerConfiguration
fn clone(&self) -> ComponentPowerConfiguration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentPowerConfiguration
impl Debug for ComponentPowerConfiguration
Sourceimpl<'a, ___E> Encode<ComponentPowerConfiguration<'static>, ___E> for &'a ComponentPowerConfigurationwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<'a, ___E> Encode<ComponentPowerConfiguration<'static>, ___E> for &'a ComponentPowerConfigurationwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ComponentPowerConfiguration<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ComponentPowerConfiguration<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ComponentPowerConfiguration<'static>, ___E> for ComponentPowerConfigurationwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
impl<___E> Encode<ComponentPowerConfiguration<'static>, ___E> for ComponentPowerConfigurationwhere
___E: InternalHandleEncoder + ?Sized + Encoder,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ComponentPowerConfiguration<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ComponentPowerConfiguration<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ComponentPowerConfiguration<'static>>, ___E> for &'a ComponentPowerConfigurationwhere
___E: Encoder + ?Sized,
&'a ComponentPowerConfiguration: Encode<ComponentPowerConfiguration<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ComponentPowerConfiguration<'static>>, ___E> for &'a ComponentPowerConfigurationwhere
___E: Encoder + ?Sized,
&'a ComponentPowerConfiguration: Encode<ComponentPowerConfiguration<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ComponentPowerConfiguration<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ComponentPowerConfiguration<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ComponentPowerConfiguration<'static>>, ___E> for ComponentPowerConfigurationwhere
___E: Encoder + ?Sized,
ComponentPowerConfiguration: Encode<ComponentPowerConfiguration<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, ComponentPowerConfiguration<'static>>, ___E> for ComponentPowerConfigurationwhere
___E: Encoder + ?Sized,
ComponentPowerConfiguration: Encode<ComponentPowerConfiguration<'static>, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ComponentPowerConfiguration<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ComponentPowerConfiguration<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<ComponentPowerConfiguration<'de>> for ComponentPowerConfiguration
impl<'de> FromWire<ComponentPowerConfiguration<'de>> for ComponentPowerConfiguration
Sourcefn from_wire(wire: ComponentPowerConfiguration<'de>) -> Self
fn from_wire(wire: ComponentPowerConfiguration<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<ComponentPowerConfiguration<'de>> for ComponentPowerConfiguration
impl<'de> FromWireRef<ComponentPowerConfiguration<'de>> for ComponentPowerConfiguration
Sourcefn from_wire_ref(wire: &ComponentPowerConfiguration<'de>) -> Self
fn from_wire_ref(wire: &ComponentPowerConfiguration<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ComponentPowerConfiguration
impl Hash for ComponentPowerConfiguration
Sourceimpl Ord for ComponentPowerConfiguration
impl Ord for ComponentPowerConfiguration
Sourcefn cmp(&self, other: &ComponentPowerConfiguration) -> Ordering
fn cmp(&self, other: &ComponentPowerConfiguration) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ComponentPowerConfiguration
impl PartialEq for ComponentPowerConfiguration
Sourcefn eq(&self, other: &ComponentPowerConfiguration) -> bool
fn eq(&self, other: &ComponentPowerConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ComponentPowerConfiguration
impl PartialOrd for ComponentPowerConfiguration
impl Eq for ComponentPowerConfiguration
impl StructuralPartialEq for ComponentPowerConfiguration