pub struct LevelTuple {
pub child_level: Option<u8>,
pub parent_level: Option<u8>,
}Expand description
Represents a dependency between two power levels of two different
PowerElements.
Fields
child_level: Option<u8>parent_level: Option<u8>Trait Implementations
Sourceimpl Clone for LevelTuple
impl Clone for LevelTuple
Sourcefn clone(&self) -> LevelTuple
fn clone(&self) -> LevelTuple
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LevelTuple
impl Debug for LevelTuple
Sourceimpl Default for LevelTuple
impl Default for LevelTuple
Sourcefn default() -> LevelTuple
fn default() -> LevelTuple
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<LevelTuple<'static>, ___E> for &'a LevelTuplewhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<LevelTuple<'static>, ___E> for &'a LevelTuplewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<LevelTuple<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<LevelTuple<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<LevelTuple<'static>, ___E> for LevelTuplewhere
___E: Encoder + ?Sized,
impl<___E> Encode<LevelTuple<'static>, ___E> for LevelTuplewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<LevelTuple<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<LevelTuple<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<LevelTuple<'de>> for LevelTuple
impl<'de> FromWire<LevelTuple<'de>> for LevelTuple
Sourcefn from_wire(wire_: LevelTuple<'de>) -> Self
fn from_wire(wire_: LevelTuple<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<LevelTuple<'de>> for LevelTuple
impl<'de> FromWireRef<LevelTuple<'de>> for LevelTuple
Sourcefn from_wire_ref(wire: &LevelTuple<'de>) -> Self
fn from_wire_ref(wire: &LevelTuple<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for LevelTuple
impl Hash for LevelTuple
Sourceimpl Ord for LevelTuple
impl Ord for LevelTuple
Sourcefn cmp(&self, other: &LevelTuple) -> Ordering
fn cmp(&self, other: &LevelTuple) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LevelTuple
impl PartialEq for LevelTuple
Sourcefn eq(&self, other: &LevelTuple) -> bool
fn eq(&self, other: &LevelTuple) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LevelTuple
impl PartialOrd for LevelTuple
impl Copy for LevelTuple
impl Eq for LevelTuple
impl StructuralPartialEq for LevelTuple