pub struct Transition {
pub target_level: Option<u8>,
pub latency_us: Option<u32>,
}Expand description
The length of time it takes to move to a power level.
target_levelis the power level we’re moving to.latency_usis the time it takes to move to the level in microseconds.
Fields
target_level: Option<u8>latency_us: Option<u32>Trait Implementations
Sourceimpl Clone for Transition
impl Clone for Transition
Sourcefn clone(&self) -> Transition
fn clone(&self) -> Transition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Transition
impl Debug for Transition
Sourceimpl Default for Transition
impl Default for Transition
Sourcefn default() -> Transition
fn default() -> Transition
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<Transition<'static>, ___E> for &'a Transitionwhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<Transition<'static>, ___E> for &'a Transitionwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<Transition<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<Transition<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<Transition<'static>, ___E> for Transitionwhere
___E: Encoder + ?Sized,
impl<___E> Encode<Transition<'static>, ___E> for Transitionwhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<Transition<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<Transition<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<Transition<'de>> for Transition
impl<'de> FromWire<Transition<'de>> for Transition
Sourcefn from_wire(wire_: Transition<'de>) -> Self
fn from_wire(wire_: Transition<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<Transition<'de>> for Transition
impl<'de> FromWireRef<Transition<'de>> for Transition
Sourcefn from_wire_ref(wire: &Transition<'de>) -> Self
fn from_wire_ref(wire: &Transition<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for Transition
impl Hash for Transition
Sourceimpl Ord for Transition
impl Ord for Transition
Sourcefn cmp(&self, other: &Transition) -> Ordering
fn cmp(&self, other: &Transition) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Transition
impl PartialEq for Transition
Sourcefn eq(&self, other: &Transition) -> bool
fn eq(&self, other: &Transition) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for Transition
impl PartialOrd for Transition
impl Copy for Transition
impl Eq for Transition
impl StructuralPartialEq for Transition