#[repr(C)]pub struct DeviceGetPowerDomainStatusResponse {
pub status: PowerDomainStatus,
}Expand description
The wire type corresponding to DeviceGetPowerDomainStatusResponse.
Fields
status: PowerDomainStatusTrait Implementations
Sourceimpl Clone for DeviceGetPowerDomainStatusResponse
impl Clone for DeviceGetPowerDomainStatusResponse
Sourcefn clone(&self) -> DeviceGetPowerDomainStatusResponse
fn clone(&self) -> DeviceGetPowerDomainStatusResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for DeviceGetPowerDomainStatusResponse
impl Constrained for DeviceGetPowerDomainStatusResponse
Sourceimpl<___D> Decode<___D> for DeviceGetPowerDomainStatusResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for DeviceGetPowerDomainStatusResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for &'a DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for &'a DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<DeviceGetPowerDomainStatusResponse, ___E> for DeviceGetPowerDomainStatusResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetPowerDomainStatusResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, DeviceGetPowerDomainStatusResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<DeviceGetPowerDomainStatusResponse, ___E> for DeviceGetPowerDomainStatusResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<PowerDomainStatus, ___E>,
impl<___E, T0> Encode<DeviceGetPowerDomainStatusResponse, ___E> for DeviceGetPowerDomainStatusResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<PowerDomainStatus, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<DeviceGetPowerDomainStatusResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
impl FromWire<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<DeviceGetPowerDomainStatusResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<DeviceGetPowerDomainStatusResponse, Self>
Sourcefn from_wire(wire: DeviceGetPowerDomainStatusResponse) -> Self
fn from_wire(wire: DeviceGetPowerDomainStatusResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
impl FromWireRef<DeviceGetPowerDomainStatusResponse> for DeviceGetPowerDomainStatusResponse
Sourcefn from_wire_ref(wire: &DeviceGetPowerDomainStatusResponse) -> Self
fn from_wire_ref(wire: &DeviceGetPowerDomainStatusResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for DeviceGetPowerDomainStatusResponse
impl IntoNatural for DeviceGetPowerDomainStatusResponse
Sourcetype Natural = DeviceGetPowerDomainStatusResponse
type Natural = DeviceGetPowerDomainStatusResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for DeviceGetPowerDomainStatusResponse
impl Wire for DeviceGetPowerDomainStatusResponse
Sourcetype Narrowed<'de> = DeviceGetPowerDomainStatusResponse
type Narrowed<'de> = DeviceGetPowerDomainStatusResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.